==> xaos_4.3.1.orig.tar.gz: XaoS-release-4.3.1/CREDITS.md <==
## Contributors

(alphabetically)

- [Anurag Aggarwal](mailto:kanurag94@gmail.com): Palette editor, palette saver, palette visualiser, Cartesian grid, batch rendering, user formulas history, powerful PNGs, bug fixes, Hindi translation, [contributions for GSoC 2020](https://github.com/xaos-project/XaoS/wiki/GSoC-2020)
- [Natalija Budinski](mailto:nbudinski@yahoo.com): Serbian translation
- [IoeCmcomc](https://github.com/IoeCmcomc): Vietnamese translation
- [Eric Courteau](mailto:ecourteau@cplus.fr): francais.cat (translation of tutorials)
- [Jean-Pierre Demailly](mailto:Jean-Pierre.Demailly@ujf-grenoble.fr): Updates for French translation
- [Radek Doulik](mailto:rodo@atrey.karlin.mff.cuni.cz): TK interface, windowid patches
- [Martin Dózsa](mailto:madsoft@centrum.cz): cs.po (Czech translation of menus)
- Árpád Fekete: some new fractals, and the 'More formulae' menu
- [Tim Goodwin](mailto:tgoodwin@cygnus.co.uk): english.cat corrections
- [Asher Gordon](mailto:AsDaGo@posteo.net): Bugfix for rendering files in a subdirectory
- [Jonas Hall](mailto:jonas.hall@norrtalje.se): Swedish translation
- Ben Hines: autoconf suggestions, Mac OS X port
- [Jan Hubička](mailto:jh@ucw.cz): Zooming routines, ugly interface, palettes, drivers, autopilot, filters, documentation, tutorials etc.
- [Jens Kilian](mailto:jjk@acm.org): BeOS driver, deutsch.cat
- [Thomas A. K. Kjaer](mailto:takjaer@imv.aau.dk): OS/2 ports (320x200 graphics and AA-lib)
- [Zbyněk Konečný](mailto:zbynek@geogebra.org): Czech translation
- [Zoltán Kovács](mailto:zoltan@geogebra.org): Internationalization, Hungarian translations, finalizing version 3.1, bug fixes, web design, WebAssembly version, current maintainer
- [Zsigmond Kovács](mailto:kovzsi@gmail.com): Fractal examples
- [Bjarnheiður Kristinsdóttir](mailto:bjarnhek@hi.is): Icelandic translation
- [J.B. Langston III](mailto:jb-langston@austin.rr.com): Native Mac OS X port (from version 3.2.2); web redesign; co-maintainer
- Alexey Loginov: Russian translation
- [Andreas Madritsch](mailto:amadritsch@datacomm.ch): New fractal types, bailout, many fixes
- [Adam Majewski](mailto:adammaj1@o2.pl): Fractal examples
- [Mateusz Malczak](mailto:xaos@malczak.info): User formula evaluation library
- [Giorgio Marazzi](mailto:gmarazzi@vtr.net): Improvements and fixes for espanhol.cat
- [Thomas Marsh](mailto:thomas.marsh2@gmail.com): First zoomer, formulae, planes, X11 driver, inversions, many ideas
- [Dominic Mazzoni](mailto:dmazzoni@cs.cmu.edu): Macintosh port (version 2.0)
- David Meleedy: Grammatical and spelling fixed version of xaos.6
- [Armin Müller](https://github.com/arm-in): Codespell fixes, translation fixes
- [Paul Nasca](mailto:zynaddsubfx@yahoo.com): Ministatus improvement
- [Nix](mailto:nix@esperi.demon.co.uk): Grammatical and spelling fixed version of xaos.hlp and other files
- [Terje Pedersen](mailto:terjepe@login.eunet.no): Amiga port
- [César Pérez](mailto:oroz@users.sourceforge.net): Spanish translations
- [Fabrice Premel](mailto:premelfa@etu.utc.fr): Periodicity checking
- [Jan Olderdissen](mailto:jan@olderdissen.com): Win32 port
- [Ilinca Sitaru](mailto:ilinca.sitaru@gmail.com): Romanian translation
- Daniel Skarda: Fractal examples
- Andrew Stone ([Stone Design](www.stone.com)): Videator Support, Cocoa improvements, performance mode, bug fixes
- [Abhishek Tiwari](mailto:tabhishek432@gmail.com): WebAssembly version, [contributions for GSoC 2023](https://github.com/tabhishek432/GSoC-2023-xaos)
- [Márton Török](mailto:marton.torok@gmail.com): Small fixes for pipes
- [Pavel Tzekov](mailto:paveltz@csoft.bg): Win32 support
- Charles Vidal: Tcl/Tk interface
- [Tapio K. Vocaldo](mailto:taps@rmx.com): Macintosh port
- Tormod Volden: Fixes for X11 driver to improve compatibility with Xorg, XScreenSaver, Beryl and Compiz
- [Clément Vermot](https://github.com/cvermot): Updates for French translation
- [Philippe Wautelet](mailto:p.wautelet@fractalzone.be): Bug fixes for version 3.1.1, French translation, gcc 4.0 fixes
- Sergio Zanchetta: Italian translation

## Included Software

XaoS uses the following libraries. These libraries may be included with some
binary distributions of XaoS.

### [Qt](https://www.qt.io/)
Copyright © 2023 The Qt Company

License GPLv2+: [GNU GPL version 2 or later](https://gnu.org/licenses/gpl.html)

### [GNU Scientific Library](https://www.gnu.org/software/gsl/)
Copyright © 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 The GSL Team

License GPLv3+: [GNU GPL version 3 or later](https://gnu.org/licenses/gpl.html)

This is free software: you are free to change and redistribute it.
There is NO WARRANTY, to the extent permitted by law.

### [libpng](http://www.libpng.org/pub/png/libpng.html)

Copyright © 1998-2008 Glenn Randers-Pehrson

Copyright © 1996-1997 Andreas Dilger

Copyright © 1995-1996 Guy Eric Schalnat, Group 42, Inc.

## Thanks

  * Unknown Samurai from Brazil (for $20 --- your email doesn't work)
  * Stanislav "XaoS" Mikes (for the name of our program)
  * Borislav Deianov (for sharing ideas)
  * Isaac Newton (for discovering his method)
  * Benoit B. Mandelbrot (for ordering the Julia sets)
  * Richard M. Stallman (for GNU)
  * Linus Torvalds (for the best kernel)
  * Tim Wegner & Bert Tyler (for Fractint)
  * Darryl House (for making code of Fractint readable)

## No thanks to

  * Bill Gates

==> xaos_4.3.2.orig.tar.gz: XaoS-release-4.3.2/CREDITS.md <==
## Contributors

(alphabetically)

- [Anurag Aggarwal](mailto:kanurag94@gmail.com): Palette editor, palette saver, palette visualiser, Cartesian grid, batch rendering, user formulas history, powerful PNGs, bug fixes, Hindi translation, [contributions for GSoC 2020](https://github.com/xaos-project/XaoS/wiki/GSoC-2020)
- [Emine Nur Ünveren Bilgiç](mailto:eminenurbilgic@duzce.edu.tr): Turkish translation
- [Natalija Budinski](mailto:nbudinski@yahoo.com): Serbian translation
- [IoeCmcomc](https://github.com/IoeCmcomc): Vietnamese translation
- [Eric Courteau](mailto:ecourteau@cplus.fr): francais.cat (translation of tutorials)
- [Jean-Pierre Demailly](mailto:Jean-Pierre.Demailly@ujf-grenoble.fr): Updates for French translation
- [Radek Doulik](mailto:rodo@atrey.karlin.mff.cuni.cz): TK interface, windowid patches
- [Martin Dózsa](mailto:madsoft@centrum.cz): cs.po (Czech translation of menus)
- Árpád Fekete: some new fractals, and the 'More formulae' menu
- [Selen Galiç](mailto:selengalic@gmail.com): Turkish translation
- [Tim Goodwin](mailto:tgoodwin@cygnus.co.uk): english.cat corrections
- [Asher Gordon](mailto:AsDaGo@posteo.net): Bugfix for rendering files in a subdirectory
- [Jonas Hall](mailto:jonas.hall@norrtalje.se): Swedish translation
- Ben Hines: autoconf suggestions, Mac OS X port
- [Jan Hubička](mailto:jh@ucw.cz): Zooming routines, ugly interface, palettes, drivers, autopilot, filters, documentation, tutorials etc.
- [Jens Kilian](mailto:jjk@acm.org): BeOS driver, deutsch.cat
- [Thomas A. K. Kjaer](mailto:takjaer@imv.aau.dk): OS/2 ports (320x200 graphics and AA-lib)
- [Zbyněk Konečný](mailto:zbynek@geogebra.org): Czech translation
- [Zoltán Kovács](mailto:zoltan@geogebra.org): Internationalization, Hungarian translations, finalizing version 3.1, bug fixes, web design, WebAssembly version, current maintainer
- [Zsigmond Kovács](mailto:kovzsi@gmail.com): Fractal examples
- [Bjarnheiður Kristinsdóttir](mailto:bjarnhek@hi.is): Icelandic translation
- [J.B. Langston III](mailto:jb-langston@austin.rr.com): Native Mac OS X port (from version 3.2.2); web redesign; co-maintainer
- Alexey Loginov: Russian translation
- [Andreas Madritsch](mailto:amadritsch@datacomm.ch): New fractal types, bailout, many fixes
- [Adam Majewski](mailto:adammaj1@o2.pl): Fractal examples
- [Mateusz Malczak](mailto:xaos@malczak.info): User formula evaluation library
- [Giorgio Marazzi](mailto:gmarazzi@vtr.net): Improvements and fixes for espanhol.cat
- [Thomas Marsh](mailto:thomas.marsh2@gmail.com): First zoomer, formulae, planes, X11 driver, inversions, many ideas
- [Dominic Mazzoni](mailto:dmazzoni@cs.cmu.edu): Macintosh port (version 2.0)
- David Meleedy: Grammatical and spelling fixed version of xaos.6
- [Armin Müller](https://github.com/arm-in): Codespell fixes, translation fixes
- [Paul Nasca](mailto:zynaddsubfx@yahoo.com): Ministatus improvement
- [Nix](mailto:nix@esperi.demon.co.uk): Grammatical and spelling fixed version of xaos.hlp and other files
- [Terje Pedersen](mailto:terjepe@login.eunet.no): Amiga port
- [César Pérez](mailto:oroz@users.sourceforge.net): Spanish translations
- [Fabrice Premel](mailto:premelfa@etu.utc.fr): Periodicity checking
- [Jan Olderdissen](mailto:jan@olderdissen.com): Win32 port
- [Ilinca Sitaru](mailto:ilinca.sitaru@gmail.com): Romanian translation
- Daniel Skarda: Fractal examples
- Andrew Stone ([Stone Design](www.stone.com)): Videator Support, Cocoa improvements, performance mode, bug fixes
- [Abhishek Tiwari](mailto:tabhishek432@gmail.com): WebAssembly version, [contributions for GSoC 2023](https://github.com/tabhishek432/GSoC-2023-xaos)
- [Márton Török](mailto:marton.torok@gmail.com): Small fixes for pipes
- [Pavel Tzekov](mailto:paveltz@csoft.bg): Win32 support
- [Zuhal Ünan](mailto:zuhalu@omu.edu.tr): Turkish translation
- Charles Vidal: Tcl/Tk interface
- [Tapio K. Vocaldo](mailto:taps@rmx.com): Macintosh port
- Tormod Volden: Fixes for X11 driver to improve compatibility with Xorg, XScreenSaver, Beryl and Compiz
- [Clément Vermot](https://github.com/cvermot): Updates for French translation
- [Philippe Wautelet](mailto:p.wautelet@fractalzone.be): Bug fixes for version 3.1.1, French translation, gcc 4.0 fixes
- [Veysel Yıldız](mailto:veyselyildiz11@gmail.com): Turkish translation
- Sergio Zanchetta: Italian translation

## Included Software

XaoS uses the following libraries. These libraries may be included with some
binary distributions of XaoS.

### [Qt](https://www.qt.io/)
Copyright © 2023 The Qt Company

License GPLv2+: [GNU GPL version 2 or later](https://gnu.org/licenses/gpl.html)

### [GNU Scientific Library](https://www.gnu.org/software/gsl/)
Copyright © 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 The GSL Team

License GPLv3+: [GNU GPL version 3 or later](https://gnu.org/licenses/gpl.html)

This is free software: you are free to change and redistribute it.
There is NO WARRANTY, to the extent permitted by law.

### [libpng](http://www.libpng.org/pub/png/libpng.html)

Copyright © 1998-2008 Glenn Randers-Pehrson

Copyright © 1996-1997 Andreas Dilger

Copyright © 1995-1996 Guy Eric Schalnat, Group 42, Inc.

## Thanks

  * Unknown Samurai from Brazil (for $20 --- your email doesn't work)
  * Stanislav "XaoS" Mikes (for the name of our program)
  * Borislav Deianov (for sharing ideas)
  * Isaac Newton (for discovering his method)
  * Benoit B. Mandelbrot (for ordering the Julia sets)
  * Richard M. Stallman (for GNU)
  * Linus Torvalds (for the best kernel)
  * Tim Wegner & Bert Tyler (for Fractint)
  * Darryl House (for making code of Fractint readable)

## No thanks to

  * Bill Gates
